@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@
 #include <QDebug>
 #include <QScrollArea>
 #include <QKeyEvent>
-#include <QSettings>
 
 
 /////////////////////// Local includes
@@ -47,11 +46,12 @@
 #include "CalculatorWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
 
 
 CalculatorChemPadDlg::CalculatorChemPadDlg(CalculatorWnd *parent)
@@ -107,20 +107,19 @@ CalculatorChemPadDlg::keyPressEvent(QKeyEvent *event)
 {
   Qt::KeyboardModifiers modifiers = event->modifiers();
 
-  int formula_handling = static_cast<int>(mp_parentWnd->m_formulaHandling);
+  int formulaHandling = mp_parentWnd->m_formulaHandling;
 
   if(modifiers & Qt::ControlModifier)
     {
-      formula_handling |= static_cast<int>(FormulaHandling::PRINT);
+      formulaHandling |= FORMULA_HANDLING_PRINT;
     }
 
   if(modifiers & Qt::ShiftModifier)
     {
-      formula_handling |= static_cast<int>(FormulaHandling::WITH_SPACE);
+      formulaHandling |= FORMULA_HANDLING_WITH_SPACE;
     }
 
-  mp_parentWnd->setFormulaHandling(
-    static_cast<FormulaHandling>(formula_handling));
+  mp_parentWnd->setFormulaHandling(formulaHandling);
 
   return event->accept();
 }
@@ -129,22 +128,23 @@ CalculatorChemPadDlg::keyPressEvent(QKeyEvent *event)
 void
 CalculatorChemPadDlg::keyReleaseEvent(QKeyEvent *event)
 {
+  CalculatorWnd *wnd = static_cast<CalculatorWnd *>(parentWidget());
+
   Qt::KeyboardModifiers modifiers = event->modifiers();
 
-  int formula_handling = static_cast<int>(mp_parentWnd->m_formulaHandling);
+  int formulaHandling = wnd->m_formulaHandling;
 
   if(!(modifiers & Qt::ControlModifier))
     {
-      formula_handling &= ~static_cast<int>(FormulaHandling::PRINT);
+      formulaHandling &= ~FORMULA_HANDLING_PRINT;
     }
 
   if(!(modifiers & Qt::ShiftModifier))
     {
-      formula_handling &= ~static_cast<int>(FormulaHandling::WITH_SPACE);
+      formulaHandling &= ~FORMULA_HANDLING_WITH_SPACE;
     }
 
-  mp_parentWnd->setFormulaHandling(
-    static_cast<FormulaHandling>(formula_handling));
+  wnd->setFormulaHandling(formulaHandling);
 
   return event->accept();
 }
@@ -174,7 +174,7 @@ CalculatorChemPadDlg::parseColumnCount(QString &line)
 QColor
 CalculatorChemPadDlg::parseColor(QString &line)
 {
-  QStringList list = line.split("%", Qt::SkipEmptyParts);
+  QStringList list = line.split("%", QString::SkipEmptyParts);
 
   // The first item of the list is "color", which we have to
   // remove.
@@ -199,7 +199,7 @@ CalculatorChemPadDlg::parseColor(QString &line)
 
   // The rgb specification is the second item in the list (index 1)
 
-  QStringList rgbList = list.at(1).split(",", Qt::SkipEmptyParts);
+  QStringList rgbList = list.at(1).split(",", QString::SkipEmptyParts);
 
   bool ok = false;
 
@@ -285,7 +285,7 @@ CalculatorChemPadDlg::parseSeparator(QString &line)
 
   QStringList list;
 
-  list = line.split("%", Qt::SkipEmptyParts);
+  list = line.split("%", QString::SkipEmptyParts);
 
   // The first item is the "chempadgroup" string.
   list.removeFirst();
@@ -314,7 +314,7 @@ CalculatorChemPadDlg::parseKey(QString &line, QStringList &list)
   CalculatorWnd *wnd    = static_cast<CalculatorWnd *>(parentWidget());
   ChemPadButton *button = 0;
 
-  list = line.split("%", Qt::SkipEmptyParts);
+  list = line.split("%", QString::SkipEmptyParts);
 
   // The first item of the list is "chempadkey", which we have to
   // remove.
@@ -376,7 +376,7 @@ CalculatorChemPadDlg::parseKey(QString &line, QStringList &list)
 
       // We are left with "bgHex,fgHex"
 
-      QStringList colorList = colorSpec.split(",", Qt::SkipEmptyParts);
+      QStringList colorList = colorSpec.split(",", QString::SkipEmptyParts);
       if(colorList.size() != 2)
         {
           qDebug() << __FILE__ << __LINE__
@@ -440,8 +440,6 @@ CalculatorChemPadDlg::parseKey(QString &line, QStringList &list)
 bool
 CalculatorChemPadDlg::setup(QString &filePath, const QString &polChemDefName)
 {
-  setWindowIcon(qApp->windowIcon());
-
   QFile file(filePath);
   if(!file.open(QFile::ReadOnly))
     {
@@ -676,6 +674,6 @@ CalculatorChemPadDlg::close()
   wnd->chemPadDlgClosed();
 }
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
