@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,10 +30,9 @@
  * END software license
  */
 
-#pragma once
 
-
-/////////////////////// stdlib includes
+#ifndef CALCULATOR_CHEM_PAD_GROUPBOX_HPP
+#define CALCULATOR_CHEM_PAD_GROUPBOX_HPP
 
 
 /////////////////////// Qt includes
@@ -43,25 +42,17 @@
 #include <QFrame>
 #include <QGridLayout>
 
-
-/////////////////////// pappsomspp includes
-
-
-/////////////////////// libXpertMass includes
-
-
-/////////////////////// libXpertMassGui includes
-
-
 /////////////////////// Local includes
 #include "ChemPadButton.hpp"
 
 
-namespace MsXpS
-{
-namespace MassXpert
+namespace msxps
 {
 
+	namespace massxpert
+	{
+
+
 
 class CalculatorChemPadGroupBox : public QGroupBox
 {
@@ -86,6 +77,9 @@ class CalculatorChemPadGroupBox : public QGroupBox
   void toggled(bool);
 };
 
+} // namespace massxpert
 
-} // namespace MassXpert
-} // namespace MsXpS
+} // namespace msxps
+
+
+#endif // CALCULATOR_CHEM_PAD_GROUPBOX_HPP
