@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,42 +30,29 @@
  * END software license
  */
 
-/////////////////////// stdlib includes
-
 
 /////////////////////// Qt includes
 #include <QApplication>
 #include <QDrag>
 #include <QDebug>
 #include <QMouseEvent>
-#include <QMessageBox>
-#include <QFileInfo>
-#include <QHeaderView>
-#include <QMenu>
-
-/////////////////////// pappsomspp includes
-
-
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/Oligomer.hpp>
-
-
-/////////////////////// libXpertMassGui includes
-
-
-/////////////////////// Local includes
+#include <QMessageBox> 
+/////////////////////// Local includes 
 #include "../nongui/globals.hpp"
 #include "CleaveOligomerTableView.hpp"
 #include "CleaveOligomerTableViewSortProxyModel.hpp"
+#include "../nongui/Oligomer.hpp"
 #include "CleavageDlg.hpp"
 #include "CleaveOligomerTableViewMimeData.hpp"
 
 
-namespace MsXpS
-{
-namespace MassXpert
+namespace msxps
 {
 
+	namespace massxpert
+	{
+
+
 
 CleaveOligomerTableView::CleaveOligomerTableView(QWidget *parent)
   : QTableView(parent)
@@ -115,17 +102,16 @@ CleaveOligomerTableView::~CleaveOligomerTableView()
 
 
 void
-CleaveOligomerTableView::setOligomerCollection(
-  libXpertMassCore::OligomerCollection *oligomers_p)
+CleaveOligomerTableView::setOligomerList(OligomerList *oligomerList)
 {
-  mp_oligomers = oligomers_p;
+  mp_oligomerList = oligomerList;
 }
 
 
-const libXpertMassCore::OligomerCollection *
-CleaveOligomerTableView::getOligomers()
+const OligomerList *
+CleaveOligomerTableView::oligomerList()
 {
-  return mp_oligomers;
+  return mp_oligomerList;
 }
 
 
@@ -142,26 +128,28 @@ CleaveOligomerTableView::setParentDlg(CleavageDlg *dlg)
   mp_parentDlg = dlg;
 }
 
-// The oligomers are deep-copied from this object's mp_oligomers container
-// into the oligomers argument to this function.
+
 int
-CleaveOligomerTableView::selectedOligomers(
-  libXpertMassCore::OligomerCollection &oligomers, int index) const
+CleaveOligomerTableView::selectedOligomers(OligomerList *oligomerList,
+                                           int index) const
 {
+  if(!oligomerList)
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
+
   int count = 0;
 
   int localIndex = 0;
 
   // How many oligomers are there in the list passed as argument?
-  int oligomerCount = oligomers.size();
+  int oligomerCount = oligomerList->size();
 
   if(index > oligomerCount)
-    qFatal() << "Programming error.";
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   // If index is -1 , then we are asked to append the oligomers to
   // the list.
   if(index == -1)
-    localIndex = oligomers.size();
+    localIndex = oligomerList->size();
 
   // For each selected oligomer, duplicate it and append to the list
   // passed as argument.
@@ -189,7 +177,7 @@ CleaveOligomerTableView::selectedOligomers(
   // each cell for each column, and there are 7 columns. Thus, when
   // we iterate in the modelIndexList, we'll have to take care of
   // this and make sure we are not putting each selected row's
-  // oligomer seven times. For this, we make sure we are not
+  // oligomer sevent times. For this, we make sure we are not
   // handling the same row twice or more, by storing the processed
   // rows in a list of integers and by checking for existence of
   // that row each time a new index is processed.
@@ -212,31 +200,21 @@ CleaveOligomerTableView::selectedOligomers(
       else
         processedRowList.append(row);
 
-      // Older version
-      // Oligomer *oligomer =
-      // static_cast<Oligomer *>(mp_oligomers.at(row).get());
-      // OligomerSPtr new_oligomer_sp =
-      // std::make_shared<Oligomer>(*oligomer);
+      CleaveOligomer *oligomer =
+        static_cast<CleaveOligomer *>(mp_oligomerList->at(row));
 
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersRef().at(row);
-
-      libXpertMassCore::OligomerSPtr new_oligomer_sp =
-        std::make_shared<libXpertMassCore::Oligomer>(*oligomer_sp);
+      CleaveOligomer *newOligomer = new CleaveOligomer(*oligomer);
 
       // Create a NoDeletePointerProp, which might be used later by
       // the user of the list of oligomers to highlight regions in
       // the sequence editor.
 
-      libXpertMassCore::NoDeletePointerProp *prop =
-        new libXpertMassCore::NoDeletePointerProp(
-          "SEQUENCE_EDITOR_WND",
-          static_cast<void *>(mp_parentDlg->editorWnd()));
+      NoDeletePointerProp *prop = new NoDeletePointerProp(
+        "SEQUENCE_EDITOR_WND", static_cast<void *>(mp_parentDlg->editorWnd()));
 
-      new_oligomer_sp->appendProp(prop);
+      newOligomer->appendProp(prop);
 
-      oligomers.getOligomersRef().insert(
-        oligomers.getOligomersRef().begin() + localIndex, new_oligomer_sp);
+      oligomerList->insert(localIndex, newOligomer);
 
       ++localIndex;
       ++count;
@@ -247,22 +225,22 @@ CleaveOligomerTableView::selectedOligomers(
 
 
 QString *
-CleaveOligomerTableView::describeSelectedOligomersAsPlainText(
+CleaveOligomerTableView::selectedOligomersAsPlainText(
   const QString &pattern,
   QString delimiter,
-  bool with_sequence,
-  bool for_xpert_miner,
-  libXpertMassCore::Enums::MassType mass_type) const
+  bool withSequence,
+  bool forXpertMiner,
+  MassType massType) const
 {
-  // Let's get all the currently selected oligomers in one container. Note that
-  //  the Oligomer instances in oligomers are allocated fully for us. We will
-  //  thefore free them upon use below.
-  libXpertMassCore::OligomerCollection oligomers;
-  std::size_t oligomers_count = selectedOligomers(oligomers, -1);
+  // Let's get all the currently selected oligomers in one list.
+  OligomerList oligomerList;
+
+  // Append the selected oligomers to the empty list.
+  int appendedOligomerCount = selectedOligomers(&oligomerList, -1);
 
   // Sanity check
-  if(oligomers_count != oligomers.size())
-    qFatal() << "Programming error.";
+  if(appendedOligomerCount != oligomerList.size())
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   // There are two possibilities:
   // 1. The pattern string is not empty, in which case it should be used to
@@ -272,7 +250,7 @@ CleaveOligomerTableView::describeSelectedOligomersAsPlainText(
 
   bool withPattern;
 
-  if(pattern.isEmpty() || for_xpert_miner)
+  if(pattern.isEmpty() || forXpertMiner)
     {
       withPattern = false;
 
@@ -291,48 +269,39 @@ CleaveOligomerTableView::describeSelectedOligomersAsPlainText(
   // Slot to get the text from the called functions.
   QString *text = nullptr;
 
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_iterator =
-    oligomers.getOligomersRef().begin();
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_end_iterator =
-    oligomers.getOligomersRef().end();
-
-  while(the_iterator != the_end_iterator)
+  while(!oligomerList.isEmpty())
     {
+      CleaveOligomer *oligomer =
+        static_cast<CleaveOligomer *>(oligomerList.takeFirst());
+
       if(withPattern)
         {
-          text = describeOligomerAsPlainTextWithPattern((*the_iterator).get(),
-                                                        pattern);
-
+          text = selectedOligomersAsPlainTextWithPattern(oligomer, pattern);
           if(text == nullptr)
-            qFatal() << "Programming error.";
-
-          *output += *text;
+            qFatal(
+              "Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
+          *output += text;
           delete text;
         }
       else
         {
-          text = describeOligomerAsPlainTextWithDelimiter((*the_iterator).get(),
-                                                          delimiter,
-                                                          with_sequence,
-                                                          for_xpert_miner,
-                                                          mass_type);
+          text = selectedOligomersAsPlainTextWithDelimiter(
+            oligomer, delimiter, withSequence, forXpertMiner, massType);
           if(text == nullptr)
-            qFatal() << "Programming error.";
-
-          *output += *text;
+            qFatal(
+              "Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
+          *output += text;
           delete text;
         }
 
-      ++the_iterator;
+      // At this point we have done the work for the current oligomer, make
+      // sure we delete it now.
 
-      // The version below is buggy. See oligomers.clear() below.
-      // the_iterator = oligomers.getOligomersRef().erase(the_iterator);
+      delete oligomer;
     }
 
-  oligomers.clear();
-
   // Terminate the string with a new line.
   *output += QString("\n");
 
@@ -341,73 +310,65 @@ CleaveOligomerTableView::describeSelectedOligomersAsPlainText(
 
 
 QString *
-CleaveOligomerTableView::describeOligomerAsPlainTextWithDelimiter(
-  libXpertMassCore::Oligomer *oligomer_p,
+CleaveOligomerTableView::selectedOligomersAsPlainTextWithDelimiter(
+  Oligomer *p_oligomer,
   const QString &delimiter,
-  bool with_sequence,
-  bool for_xpert_miner,
-  libXpertMassCore::Enums::MassType massType) const
+  bool withSequence,
+  bool forXpertMiner,
+  MassType massType) const
 {
-  if(oligomer_p == nullptr)
-    qFatal() << "Programming error.";
+  if(p_oligomer == nullptr)
+    qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
   // For export to XpertMiner, we only want the masses asked for:
-  // libXpertMassCore::Enums::MassType::MONO or AVG. Also, we want the format to
-  // be: mass <delim> charge <delim> name <delim> coords
+  // MassType::MASS_MONO or MASS_AVG. Also, we want the format to be :
+
+  // mass <delim> charge <delim> name <delim> coords
 
   QString *text = new QString;
 
-  if(!for_xpert_miner)
-    *text += QString("\n%1%2").arg(oligomer_p->getDescription()).arg(delimiter);
+  if(!forXpertMiner)
+    *text += QString("\n%1%2").arg(p_oligomer->description()).arg(delimiter);
 
-  if(for_xpert_miner && massType == libXpertMassCore::Enums::MassType::AVG)
+  if(forXpertMiner && massType == MassType::MASS_AVG)
     {
     }
   else
     {
       *text += QString("%1%2")
-                 .arg(oligomer_p->getMass(libXpertMassCore::Enums::MassType::MONO),
-                      0,
-                      'f',
-                      libXpertMassCore::OLIGOMER_DEC_PLACES)
+                 .arg(p_oligomer->monoString(OLIGOMER_DEC_PLACES))
                  .arg(delimiter);
     }
 
-  if(for_xpert_miner && massType == libXpertMassCore::Enums::MassType::MONO)
+  if(forXpertMiner && massType == MassType::MASS_MONO)
     {
     }
   else
     {
       *text += QString("%1%2")
-                 .arg(oligomer_p->getMass(libXpertMassCore::Enums::MassType::AVG),
-                      0,
-                      'f',
-                      libXpertMassCore::OLIGOMER_DEC_PLACES)
+                 .arg(p_oligomer->avgString(OLIGOMER_DEC_PLACES))
                  .arg(delimiter);
     }
 
-  *text +=
-    QString("%1%2").arg(oligomer_p->getIonizerCstRef().charge()).arg(delimiter);
+  *text += QString("%1%2").arg(p_oligomer->charge()).arg(delimiter);
 
-  *text += QString("%1%2").arg(oligomer_p->getName()).arg(delimiter);
+  *text += QString("%1%2").arg(p_oligomer->name()).arg(delimiter);
 
   *text += QString("%1%2")
-             .arg(oligomer_p->getCalcOptionsCstRef()
-                    .getIndexRangeCollectionCstRef()
-                    .positionsAsText())
+             .arg(static_cast<CoordinateList *>(p_oligomer)->positionsAsText())
              .arg(delimiter);
 
-  if(!for_xpert_miner)
-    *text += QString("%1%2").arg(oligomer_p->isModified()).arg(delimiter);
+  if(!forXpertMiner)
+    *text += QString("%1%2").arg(p_oligomer->isModified()).arg(delimiter);
 
   // We cannot export the sequence if data are for XpertMiner
-  if(!for_xpert_miner && with_sequence)
+  if(!forXpertMiner && withSequence)
     {
-      const QString sequence =
-        oligomer_p->getPolymerCstSPtr()->getSequenceCstRef().getSequence(
-          oligomer_p->getCalcOptionsCstRef().getIndexRangeCollectionCstRef());
+      QString *sequence = p_oligomer->monomerText();
 
-      *text += QString("\n%1").arg(sequence);
+      *text += QString("\n%1").arg(*sequence);
+
+      delete sequence;
     }
 
   // Terminate the stanza
@@ -418,8 +379,8 @@ CleaveOligomerTableView::describeOligomerAsPlainTextWithDelimiter(
 
 
 QString *
-CleaveOligomerTableView::describeOligomerAsPlainTextWithPattern(
-  libXpertMassCore::Oligomer *oligomer_p, const QString &pattern) const
+CleaveOligomerTableView::selectedOligomersAsPlainTextWithPattern(
+  Oligomer *p_oligomer, const QString &pattern) const
 {
   // We receive a pattern that we use to craft the output. The following
   // shortcuts are used:
@@ -435,14 +396,8 @@ CleaveOligomerTableView::describeOligomerAsPlainTextWithPattern(
   // %p - partial
   // %i - polymer sequence name (identity)
 
-  if(oligomer_p == nullptr)
-    qFatal() << "Programming error.";
-
-  // qDebug() << oligomer_p->getCalcOptionsCstRef()
-  //               .getIndexRangeCollectionCstRef()
-  //               .positionsAsText()
-  //          << "with name:" << oligomer_p->getName();
-
+  if(p_oligomer == nullptr)
+    qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
   QString *text = new QString;
 
@@ -498,9 +453,8 @@ CleaveOligomerTableView::describeOligomerAsPlainTextWithPattern(
 
               if(iter == pattern.size() - 1)
                 {
-                  // This is the last character of the line, then, duplicate
-                  // the newline so that it actually creates a new line in the
-                  // text.
+                  // This is the last character of the line, then, duplicate the
+                  // newline so that it actually creates a new line in the text.
 
                   *text += QString("\n");
                 }
@@ -516,63 +470,48 @@ CleaveOligomerTableView::describeOligomerAsPlainTextWithPattern(
           if(curChar == 'f')
             {
               QFileInfo fileInfo(
-                mp_parentDlg->editorWnd()->getPolymer()->getFilePath());
+                mp_parentDlg->editorWnd()->polymer()->filePath());
               if(fileInfo.exists())
                 *text += fileInfo.fileName();
               else
                 *text += "Untitled";
-
               prevChar = ' ';
               continue;
             }
           if(curChar == 'm')
             {
-              *text += QString("%1").arg(
-                oligomer_p->getMass(libXpertMassCore::Enums::MassType::MONO),
-                0,
-                'f',
-                libXpertMassCore::OLIGOMER_DEC_PLACES);
-
+              *text += p_oligomer->monoString(OLIGOMER_DEC_PLACES);
               prevChar = ' ';
               continue;
             }
           if(curChar == 'a')
             {
-              *text += QString("%1").arg(
-                oligomer_p->getMass(libXpertMassCore::Enums::MassType::AVG),
-                0,
-                'f',
-                libXpertMassCore::OLIGOMER_DEC_PLACES);
-
+              *text += p_oligomer->avgString(OLIGOMER_DEC_PLACES);
               prevChar = ' ';
               continue;
             }
           if(curChar == 'z')
             {
-              *text +=
-                QString("%1").arg(oligomer_p->getIonizerCstRef().charge());
-
+              *text += QString("%1").arg(p_oligomer->charge());
               prevChar = ' ';
               continue;
             }
           if(curChar == 's')
             {
-              *text += oligomer_p->getPolymerCstSPtr()
-                         ->getSequenceCstRef()
-                         .getSequence(oligomer_p->getCalcOptionsCstRef()
-                                        .getIndexRangeCollectionCstRef());
+              QString *sequence = p_oligomer->monomerText();
+
+              *text += *sequence;
+
+              delete sequence;
 
               prevChar = ' ';
               continue;
             }
           if(curChar == 'l')
             {
-              QString elidedSequence = libXpertMassCore::Utils::elideText(
-                oligomer_p->getPolymerCstSPtr()
-                  ->getSequenceCstRef()
-                  .getSequence(oligomer_p->getCalcOptionsCstRef()
-                                 .getIndexRangeCollectionCstRef()));
-
+              QString *sequence      = p_oligomer->monomerText();
+              QString elidedSequence = elideText(*sequence);
+              delete sequence;
               *text += elidedSequence;
 
               prevChar = ' ';
@@ -580,45 +519,44 @@ CleaveOligomerTableView::describeOligomerAsPlainTextWithPattern(
             }
           if(curChar == 'c')
             {
-              *text += oligomer_p->getCalcOptionsCstRef()
-                         .getIndexRangeCollectionCstRef()
-                         .positionsAsText();
-
+              *text +=
+                static_cast<CoordinateList *>(p_oligomer)->positionsAsText();
               prevChar = ' ';
               continue;
             }
           if(curChar == 'e')
             {
-              *text += oligomer_p->getDescription();
+              CleaveOligomer *cleaveOligomer =
+                static_cast<CleaveOligomer *>(p_oligomer);
 
+              *text += cleaveOligomer->description();
               prevChar = ' ';
               continue;
             }
           if(curChar == 'o')
             {
-              *text += QString("%1").arg(oligomer_p->isModified());
-
+              *text += QString("%1").arg(p_oligomer->isModified());
               prevChar = ' ';
               continue;
             }
           if(curChar == 'n')
             {
-              *text += oligomer_p->getName();
-
+              *text += p_oligomer->name();
               prevChar = ' ';
               continue;
             }
           if(curChar == 'p')
             {
-              *text += QString("%1").arg(oligomer_p->getPartialCleavage());
+              CleaveOligomer *cleaveOligomer =
+                static_cast<CleaveOligomer *>(p_oligomer);
 
+              *text += QString("%1").arg(cleaveOligomer->partialCleavage());
               prevChar = ' ';
               continue;
             }
           if(curChar == 'i')
             {
-              *text += mp_parentDlg->editorWnd()->getPolymer()->getName();
-
+              *text += mp_parentDlg->editorWnd()->polymer()->name();
               prevChar = ' ';
               continue;
             }
@@ -652,7 +590,7 @@ CleaveOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
     }
   else if(mouseEvent->buttons() & Qt::RightButton)
     {
-      contextMenu->popup(mouseEvent->globalPosition().toPoint());
+      contextMenu->popup(mouseEvent->globalPos());
       return;
     }
 
@@ -710,25 +648,19 @@ CleaveOligomerTableView::currentChanged(const QModelIndex &current,
   // tableView (that list actually belongs to the CleavageDlg
   // instance.
 
-  libXpertMassCore::OligomerSPtr oligomer_sp =
-    mp_oligomers->getOligomersCstRef().at(row);
+  CleaveOligomer *oligomer =
+    static_cast<CleaveOligomer *>(mp_oligomerList->at(row));
 
   // If the oligomers obtained with the cleavage are old and the
   // sequence has been changed since the cleavage, then the
   // oligomers might point to a sequence element that is no more. We
   // want to avoid such kind of errors.
 
-  if(oligomer_sp->getCalcOptionsCstRef()
-         .getIndexRangeCollectionCstRef()
-         .leftMostIndexRangeStart() >=
-       (qsizetype)oligomer_sp->getPolymerCstSPtr()->size() ||
-     oligomer_sp->getCalcOptionsCstRef()
-         .getIndexRangeCollectionCstRef()
-         .rightMostIndexRangeStop() >=
-       (qsizetype)oligomer_sp->getPolymerCstSPtr()->size())
+  if(oligomer->startIndex() >= oligomer->polymer()->size() ||
+     oligomer->endIndex() >= oligomer->polymer()->size())
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Cleavage"),
+                           tr("massXpert - Cleavage"),
                            tr("%1@%2\n"
                               "The monomer indices do not correspond "
                               "to a valid polymer sequence range.\n"
@@ -741,31 +673,31 @@ CleaveOligomerTableView::currentChanged(const QModelIndex &current,
       return;
     }
 
-  QString text =
-    oligomer_sp->getPolymerCstSPtr()->getSequenceCstRef().getSequence(
-      oligomer_sp->getCalcOptionsCstRef().getIndexRangeCollectionCstRef());
+  QString *text = oligomer->monomerText();
 
   // We are getting text for an oligomer; it cannot be empty,
   // because that would mean the oligomer has no monomers. In that
   // case it is not conceivable that the oligomer be in the cleavage
   // product list.
 
-  Q_ASSERT(!text.isEmpty());
+  Q_ASSERT(!text->isEmpty());
 
-  text += QString(" -- %1").arg(oligomer_sp->getDescription());
+  *text += QString(" -- %1").arg(oligomer->description());
 
   // Get the formula of the oligomer and display it all along.
 
-  QString formula = oligomer_sp->elementalComposition();
+  QString formula = oligomer->elementalComposition();
 
-  text += QString(" -- Formula: %1").arg(formula);
+  *text += QString("(formula: %1)").arg(formula);
 
-  mp_parentDlg->updateOligomerSequence(&text);
+  mp_parentDlg->updateOligomerSequence(text);
+
+  delete text;
 
   // Get the mass calculation engine's options out of the oligomer,
   // so that we can display them correctly.
 
-  libXpertMassCore::CalcOptions calcOptions(oligomer_sp->getCalcOptionsCstRef());
+  CalcOptions calcOptions = oligomer->calcOptions();
 
   mp_parentDlg->updateCleavageDetails(calcOptions);
 
@@ -790,25 +722,28 @@ CleaveOligomerTableView::itemActivated(const QModelIndex &index)
   // tableView (that list actually belongs to the CleavageDlg
   // instance.
 
-  libXpertMassCore::OligomerSPtr oligomer_sp =
-    mp_oligomers->getOligomersRef().at(row);
+  CleaveOligomer *oligomer =
+    static_cast<CleaveOligomer *>(mp_oligomerList->at(row));
 
-  SequenceEditorWnd *seq_editor_wnd = mp_parentDlg->editorWnd();
+  SequenceEditorWnd *editorWnd = mp_parentDlg->editorWnd();
 
-  const libXpertMassCore::IndexRangeCollection &index_range_collection =
-    oligomer_sp->getCalcOptionsCstRef().getIndexRangeCollectionCstRef();
+  CoordinateList *coordinateList = static_cast<CoordinateList *>(oligomer);
 
   // Remove the previous selection, so that we can start fresh.
-  seq_editor_wnd->mpa_editorGraphicsView->resetSelection();
+  editorWnd->mpa_editorGraphicsView->resetSelection();
 
-  foreach(const libXpertMassCore::IndexRange *item,
-          index_range_collection.getRangesCstRef())
+  for(int iter = 0; iter < coordinateList->size(); ++iter)
     {
-      if(item->m_start >= (qsizetype)oligomer_sp->getPolymerCstSPtr()->size() ||
-         item->m_stop >= (qsizetype)oligomer_sp->getPolymerCstSPtr()->size())
+      Coordinates *coordinates = coordinateList->at(iter);
+
+      int start = coordinates->start();
+      int end   = coordinates->end();
+
+      if(start >= oligomer->polymer()->size() ||
+         end >= oligomer->polymer()->size())
         {
           QMessageBox::warning(this,
-                               tr("MassXpert3 - Cleavage"),
+                               tr("massXpert - Cleavage"),
                                tr("%1@%2\n"
                                   "The monomer indices do not correspond "
                                   "to a valid polymer sequence range.\n"
@@ -821,10 +756,11 @@ CleaveOligomerTableView::itemActivated(const QModelIndex &index)
           return;
         }
 
-      seq_editor_wnd->mpa_editorGraphicsView->setSelection(*item, true, false);
+      editorWnd->mpa_editorGraphicsView->setSelection(
+        *coordinates, true, false);
     }
 
-  seq_editor_wnd->updateSelectedSequenceMasses();
+  editorWnd->updateSelectedSequenceMasses();
 }
 
 
@@ -833,21 +769,21 @@ CleaveOligomerTableView::itemActivated(const QModelIndex &index)
 void
 CleaveOligomerTableView::copyMono()
 {
-  return copyMassList(libXpertMassCore::Enums::MassType::MONO);
+  return copyMassList(MassType::MASS_MONO);
 }
 
 
 void
 CleaveOligomerTableView::copyAvg()
 {
-  return copyMassList(libXpertMassCore::Enums::MassType::AVG);
+  return copyMassList(MassType::MASS_AVG);
 }
 
 
 void
-CleaveOligomerTableView::copyMassList(libXpertMassCore::Enums::MassType mass_type)
+CleaveOligomerTableView::copyMassList(int monoOrAvg)
 {
-  QString masses_text;
+  QString massList;
 
   // We want to prepare a textual list of masses (either MONO or
   // AVG) of all the oligomers in the tableview, exactly as they are
@@ -867,25 +803,33 @@ CleaveOligomerTableView::copyMassList(libXpertMassCore::Enums::MassType mass_typ
       QModelIndex proxyIndex  = sortModel->index(iter, 0);
       QModelIndex sourceIndex = sortModel->mapToSource(proxyIndex);
 
-      int row = sourceIndex.row();
+      int sourceRow = sourceIndex.row();
 
       // qDebug() << __FILE__ << __LINE__
-      //          << "row:" << row;
+      //          << "sourceRow:" << sourceRow;
 
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersRef().at(row);
+      CleaveOligomer *oligomer =
+        static_cast<CleaveOligomer *>(mp_oligomerList->at(sourceRow));
 
-      masses_text += QString("%1\n").arg(oligomer_sp->getMass(mass_type),
-                                         0,
-                                         'f',
-                                         libXpertMassCore::OLIGOMER_DEC_PLACES);
+      if(monoOrAvg == MassType::MASS_MONO)
+        massList += oligomer->monoString(OLIGOMER_DEC_PLACES);
+      else if(monoOrAvg == MassType::MASS_AVG)
+        massList += oligomer->avgString(OLIGOMER_DEC_PLACES);
+      else
+        qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
+
+      // End the mass item with a new line.
+      massList += "\n";
     }
 
-  if(masses_text.isEmpty())
+  if(massList.isEmpty())
     return;
 
-  QApplication::clipboard()->setText(masses_text, QClipboard::Clipboard);
+  QClipboard *clipboard = QApplication::clipboard();
+
+  clipboard->setText(massList, QClipboard::Clipboard);
 }
 
-} // namespace MassXpert
-} // namespace MsXpS
+} // namespace massxpert
+
+} // namespace msxps
