@@ -33,38 +33,33 @@
 
 /////////////////////// Qt includes
 #include <QMessageBox>
-#include <QSettings>
-
-
-/////////////////////// libmass includes
-#include <libXpertMass/PolChemDef.hpp>
 
 
 /////////////////////// Local includes
 #include "FragSpecDefDlg.hpp"
+#include "../nongui/PolChemDef.hpp"
 #include "PolChemDefWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-FragSpecDefDlg::FragSpecDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
+
+FragSpecDefDlg::FragSpecDefDlg(PolChemDef *polChemDef,
                                PolChemDefWnd *polChemDefWnd,
-                               const QString &settingsFilePath,
-                               const QString &applicationName,
-                               const QString &description)
-  : AbstractPolChemDefDependentDlg(polChemDefSPtr,
-                                   polChemDefWnd,
-                                   settingsFilePath,
-                                   "FragSpecDefDlg",
-                                   applicationName,
-                                   description)
+                               const QString &settingsFilePath)
+  : AbstractPolChemDefDependentDlg{
+      polChemDef,
+      polChemDefWnd,
+      settingsFilePath,
+      "FragSpecDefDlg",
+      "massXpert: Fragmentation specification definition"}
 {
-  mp_list = polChemDefSPtr->fragSpecListPtr();
+  mp_list = polChemDef->fragSpecListPtr();
 
   if(!initialize())
     qFatal(
@@ -124,15 +119,11 @@ FragSpecDefDlg::initialize()
 {
   m_ui.setupUi(this);
 
-  // Now we need to actually show the window title (that element is empty in
-  // m_ui)
-  displayWindowTitle();
-
   // Set all the fragSpecs to the list widget.
 
   for(int iter = 0; iter < mp_list->size(); ++iter)
     {
-      libXpertMass::FragSpec *fragSpec = mp_list->at(iter);
+      FragSpec *fragSpec = mp_list->at(iter);
 
       m_ui.fragSpecListWidget->addItem(fragSpec->name());
     }
@@ -229,11 +220,10 @@ FragSpecDefDlg::addFragSpecPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libXpertMass::FragSpec *newFragSpec =
-    new libXpertMass::FragSpec(msp_polChemDef,
-                          tr("Type Spec Name"),
-                          tr("Type Spec Formula"),
-                          libXpertMass::FRAG_END_NONE);
+  FragSpec *newFragSpec = new FragSpec(mp_polChemDef,
+                                       tr("Type Spec Name"),
+                                       tr("Type Spec Formula"),
+                                       FRAG_END_NONE);
 
   mp_list->insert(index, newFragSpec);
   m_ui.fragSpecListWidget->insertItem(index, newFragSpec->name());
@@ -272,7 +262,7 @@ FragSpecDefDlg::removeFragSpecPushButtonClicked()
   QListWidgetItem *item = m_ui.fragSpecListWidget->takeItem(index);
   delete item;
 
-  libXpertMass::FragSpec *fragSpec = mp_list->takeAt(index);
+  FragSpec *fragSpec = mp_list->takeAt(index);
   Q_ASSERT(fragSpec);
   delete fragSpec;
 
@@ -385,12 +375,11 @@ FragSpecDefDlg::addFragRulePushButtonClicked()
   int index = m_ui.fragSpecListWidget->currentRow();
 
   // What's the actual fragSpec?
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Allocate the new fragRule.
-  libXpertMass::FragRule *newFragRule =
-    new libXpertMass::FragRule(msp_polChemDef, tr("Type Rule Name"));
+  FragRule *newFragRule = new FragRule(mp_polChemDef, tr("Type Rule Name"));
 
   // Get the row index of the current fragRule item. Returns -1 if the
   // list is empty.
@@ -429,7 +418,7 @@ FragSpecDefDlg::removeFragRulePushButtonClicked()
   // which fragSpec we'll remove the fragRule.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Get the index of the current fragRule.
@@ -444,9 +433,9 @@ FragSpecDefDlg::removeFragRulePushButtonClicked()
 
   // Remove the fragRule from the fragSpec proper.
 
-  QList<libXpertMass::FragRule *> fragRuleList = fragSpec->ruleList();
+  QList<FragRule *> fragRuleList = fragSpec->ruleList();
 
-  libXpertMass::FragRule *fragRule = fragRuleList.at(index);
+  FragRule *fragRule = fragRuleList.at(index);
 
   fragSpec->ruleList().removeAt(index);
   delete fragRule;
@@ -490,8 +479,8 @@ FragSpecDefDlg::moveUpFragRulePushButtonClicked()
     return;
 
   // Get the fragSpec to which the fragRule belongs.
-  int index                   = m_ui.fragSpecListWidget->currentRow();
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  int index          = m_ui.fragSpecListWidget->currentRow();
+  FragSpec *fragSpec = mp_list->at(index);
 
   // Get the index of the current fragRule item.
   index = m_ui.fragRuleListWidget->currentRow();
@@ -501,7 +490,7 @@ FragSpecDefDlg::moveUpFragRulePushButtonClicked()
     return;
 
   // Get the fragRule itself from the fragSpec.
-  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  FragRule *fragRule = fragSpec->ruleList().at(index);
 
   fragSpec->ruleList().removeAt(index);
   fragSpec->ruleList().insert(index - 1, fragRule);
@@ -529,8 +518,8 @@ FragSpecDefDlg::moveDownFragRulePushButtonClicked()
     return;
 
   // Get the fragSpec to which the fragRule belongs.
-  int index                   = m_ui.fragSpecListWidget->currentRow();
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  int index          = m_ui.fragSpecListWidget->currentRow();
+  FragSpec *fragSpec = mp_list->at(index);
 
   // Get the index of the current fragRule item.
   index = m_ui.fragRuleListWidget->currentRow();
@@ -540,7 +529,7 @@ FragSpecDefDlg::moveDownFragRulePushButtonClicked()
     return;
 
   // Get the fragRule itself from the fragSpec.
-  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  FragRule *fragRule = fragSpec->ruleList().at(index);
 
   fragSpec->ruleList().removeAt(index);
   fragSpec->ruleList().insert(index + 1, fragRule);
@@ -570,7 +559,7 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
   // Get the index of the current fragSpec item.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  FragSpec *fragSpec = mp_list->at(index);
 
   // We do not want more than one fragSpec by the same name.
 
@@ -581,7 +570,7 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
   // fragSpec is not the one that is current in the fragSpec list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libXpertMass::FragSpec::isNameInList(editName, *mp_list);
+  int nameRes = FragSpec::isNameInList(editName, *mp_list);
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -593,16 +582,16 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
     }
 
   QString fragEndString = m_ui.fragEndComboBox->currentText();
-  libXpertMass::FragEnd fragEnd;
+  MxtFragEnd fragEnd;
 
   if(fragEndString == "NE")
-    fragEnd = libXpertMass::FRAG_END_NONE;
+    fragEnd = FRAG_END_NONE;
   else if(fragEndString == "BE")
-    fragEnd = libXpertMass::FRAG_END_BOTH;
+    fragEnd = FRAG_END_BOTH;
   else if(fragEndString == "LE")
-    fragEnd = libXpertMass::FRAG_END_LEFT;
+    fragEnd = FRAG_END_LEFT;
   else if(fragEndString == "RE")
-    fragEnd = libXpertMass::FRAG_END_RIGHT;
+    fragEnd = FRAG_END_RIGHT;
   else
     {
       QMessageBox::warning(this,
@@ -615,12 +604,9 @@ FragSpecDefDlg::applyFragSpecPushButtonClicked()
 
   // At this point, validate the formula:
 
-  libXpertMass::Formula formula(editFormula);
+  Formula formula(editFormula);
 
-  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
-    msp_polChemDef->getIsotopicDataSPtr();
-
-  if(!formula.validate(isotopic_data_sp))
+  if(!formula.validate(mp_polChemDef->atomList()))
     {
       QMessageBox::warning(this,
                            tr("massXpert - Fragmentation definition"),
@@ -718,14 +704,14 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
     return;
 
   // Get the fragSpec to which the fragRule belongs.
-  int index                   = m_ui.fragSpecListWidget->currentRow();
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  int index          = m_ui.fragSpecListWidget->currentRow();
+  FragSpec *fragSpec = mp_list->at(index);
 
   // Get the index of the current fragRule item.
   index = m_ui.fragRuleListWidget->currentRow();
 
   // Get the fragRule itself from the fragSpec.
-  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  FragRule *fragRule = fragSpec->ruleList().at(index);
 
   QString editName    = m_ui.fragRuleNameLineEdit->text();
   QString editFormula = m_ui.fragRuleFormulaLineEdit->text();
@@ -738,7 +724,7 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
   // fragRule is not the one that is current in the fragRule list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libXpertMass::FragRule::isNameInList(editName, fragSpec->ruleList());
+  int nameRes = FragRule::isNameInList(editName, fragSpec->ruleList());
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -751,10 +737,9 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   if(!prevCode.isEmpty())
     {
-      const QList<libXpertMass::Monomer *> &monomerList =
-        msp_polChemDef->monomerList();
+      const QList<Monomer *> &monomerList = mp_polChemDef->monomerList();
 
-      if(libXpertMass::Monomer::isCodeInList(prevCode, monomerList) == -1)
+      if(Monomer::isCodeInList(prevCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Fragmentation definition"),
@@ -766,10 +751,9 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   if(!currCode.isEmpty())
     {
-      const QList<libXpertMass::Monomer *> &monomerList =
-        msp_polChemDef->monomerList();
+      const QList<Monomer *> &monomerList = mp_polChemDef->monomerList();
 
-      if(libXpertMass::Monomer::isCodeInList(currCode, monomerList) == -1)
+      if(Monomer::isCodeInList(currCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Fragmentation definition"),
@@ -781,10 +765,9 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
 
   if(!nextCode.isEmpty())
     {
-      const QList<libXpertMass::Monomer *> &monomerList =
-        msp_polChemDef->monomerList();
+      const QList<Monomer *> &monomerList = mp_polChemDef->monomerList();
 
-      if(libXpertMass::Monomer::isCodeInList(nextCode, monomerList) == -1)
+      if(Monomer::isCodeInList(nextCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Fragmentation definition"),
@@ -794,12 +777,9 @@ FragSpecDefDlg::applyFragRulePushButtonClicked()
         }
     }
 
-  libXpertMass::Formula formula(editFormula);
+  Formula formula(editFormula);
 
-  libXpertMass::IsotopicDataSPtr isotopic_data_sp =
-    msp_polChemDef->getIsotopicDataSPtr();
-
-  if(!formula.validate(isotopic_data_sp))
+  if(!formula.validate(mp_polChemDef->atomList()))
     {
       QMessageBox::warning(this,
                            tr("massXpert - Fragmentation definition"),
@@ -858,7 +838,7 @@ FragSpecDefDlg::validatePushButtonClicked()
     {
       QListWidgetItem *item = m_ui.fragSpecListWidget->item(iter);
 
-      libXpertMass::FragSpec *fragSpec = mp_list->at(iter);
+      FragSpec *fragSpec = mp_list->at(iter);
 
       if(item->text() != fragSpec->name())
         errorList << QString(tr("\nFragmentation at index %1 has not "
@@ -910,7 +890,7 @@ FragSpecDefDlg::fragSpecListWidgetItemSelectionChanged()
   // Get the index of the current fragSpec.
   int index = m_ui.fragSpecListWidget->currentRow();
 
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Set the data of the fragSpec to their respective widgets.
@@ -921,7 +901,7 @@ FragSpecDefDlg::fragSpecListWidgetItemSelectionChanged()
 
   for(int iter = 0; iter < fragSpec->ruleList().size(); ++iter)
     {
-      libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(iter);
+      FragRule *fragRule = fragSpec->ruleList().at(iter);
 
       m_ui.fragRuleListWidget->addItem(fragRule->name());
     }
@@ -953,7 +933,7 @@ FragSpecDefDlg::fragRuleListWidgetItemSelectionChanged()
   int index = m_ui.fragSpecListWidget->currentRow();
 
   // Find the fragRule object in the list of fragRules.
-  libXpertMass::FragSpec *fragSpec = mp_list->at(index);
+  FragSpec *fragSpec = mp_list->at(index);
   Q_ASSERT(fragSpec);
 
   // Get the index of the current fragRule.
@@ -961,7 +941,7 @@ FragSpecDefDlg::fragRuleListWidgetItemSelectionChanged()
 
   // Get the fragRule that is currently selected from the fragSpec's list
   // of fragRules.
-  libXpertMass::FragRule *fragRule = fragSpec->ruleList().at(index);
+  FragRule *fragRule = fragSpec->ruleList().at(index);
   Q_ASSERT(fragRule);
 
   // Set the data of the fragRule to their respective widgets.
@@ -970,7 +950,7 @@ FragSpecDefDlg::fragRuleListWidgetItemSelectionChanged()
 
 
 void
-FragSpecDefDlg::updateFragSpecDetails(libXpertMass::FragSpec *fragSpec)
+FragSpecDefDlg::updateFragSpecDetails(FragSpec *fragSpec)
 {
   if(fragSpec)
     {
@@ -979,11 +959,11 @@ FragSpecDefDlg::updateFragSpecDetails(libXpertMass::FragSpec *fragSpec)
 
       int index = 0;
 
-      if(fragSpec->fragEnd() == libXpertMass::FRAG_END_NONE)
+      if(fragSpec->fragEnd() == FRAG_END_NONE)
         index = m_ui.fragEndComboBox->findText("NE");
-      else if(fragSpec->fragEnd() == libXpertMass::FRAG_END_LEFT)
+      else if(fragSpec->fragEnd() == FRAG_END_LEFT)
         index = m_ui.fragEndComboBox->findText("LE");
-      else if(fragSpec->fragEnd() == libXpertMass::FRAG_END_RIGHT)
+      else if(fragSpec->fragEnd() == FRAG_END_RIGHT)
         index = m_ui.fragEndComboBox->findText("RE");
       m_ui.fragEndComboBox->setCurrentIndex(index);
       m_ui.monomerContributionSpinBox->setValue(
@@ -1003,7 +983,7 @@ FragSpecDefDlg::updateFragSpecDetails(libXpertMass::FragSpec *fragSpec)
 
 
 void
-FragSpecDefDlg::updateFragRuleDetails(libXpertMass::FragRule *fragRule)
+FragSpecDefDlg::updateFragRuleDetails(FragRule *fragRule)
 {
   if(fragRule)
     {
@@ -1061,4 +1041,4 @@ FragSpecDefDlg::validate()
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
