@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,42 +31,29 @@
  */
 
 
-/////////////////////// stdlib includes
-
-
 /////////////////////// Qt includes
 #include <QDebug>
 #include <QHeaderView>
 #include <QMouseEvent>
 #include <QMessageBox>
 #include <QDrag>
-#include <QMenu>
-
-
-/////////////////////// pappsomspp includes
-#include <pappsomspp/core/utils.h>
-
-
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/Oligomer.hpp>
-
-
-/////////////////////// libXpertMassGui includes
 
 
 /////////////////////// Local includes
 #include "../nongui/globals.hpp"
 #include "FragmentOligomerTableView.hpp"
 #include "FragmentOligomerTableViewSortProxyModel.hpp"
+#include "../nongui/Oligomer.hpp"
 #include "FragmentationDlg.hpp"
 #include "FragmentOligomerTableViewMimeData.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
 
 
 FragmentOligomerTableView::FragmentOligomerTableView(QWidget *parent)
@@ -116,17 +103,16 @@ FragmentOligomerTableView::~FragmentOligomerTableView()
 
 
 void
-FragmentOligomerTableView::setOligomerCollection(
-  libXpertMassCore::OligomerCollection *oligomers)
+FragmentOligomerTableView::setOligomerList(OligomerList *oligomerList)
 {
-  mp_oligomers = oligomers;
+  mp_oligomerList = oligomerList;
 }
 
 
-const libXpertMassCore::OligomerCollection *
-FragmentOligomerTableView::getOligomers()
+const OligomerList *
+FragmentOligomerTableView::oligomerList()
 {
-  return mp_oligomers;
+  return mp_oligomerList;
 }
 
 
@@ -143,28 +129,28 @@ FragmentOligomerTableView::setParentDlg(FragmentationDlg *dlg)
   mp_parentDlg = dlg;
 }
 
-// The oligomers OligomerCollection might not be empty and
-// index indicates at what index to insert the currently
-// selected oligomers. If index = -1, then the oligomers
-// need to be simply appended.
+
 int
-FragmentOligomerTableView::selectedOligomers(
-  libXpertMassCore::OligomerCollection &oligomers, int index) const
+FragmentOligomerTableView::selectedOligomers(OligomerList *oligomerList,
+                                             int index) const
 {
+  if(!oligomerList)
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
+
   int count = 0;
 
-  int oligomers_insertion_index = 0;
+  int localIndex = 0;
 
   // How many oligomers are there in the list passed as argument?
-  int oligomerCount = oligomers.size();
+  int oligomerCount = oligomerList->size();
 
   if(index > oligomerCount)
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   // If index is -1 , then we are asked to append the oligomers to
-  // the list (that is, to insert past the last item).
+  // the list.
   if(index == -1)
-    oligomers_insertion_index = oligomers.size();
+    localIndex = oligomerList->size();
 
   // For each selected oligomer, duplicate it and append to the list
   // passed as argument.
@@ -197,9 +183,6 @@ FragmentOligomerTableView::selectedOligomers(
   // rows in a list of integers and by checking for existence of
   // that row each time a new index is processed.
 
-  // For debugging.
-  QString row_text;
-
   QList<int> processedRowList;
 
   for(int iter = 0; iter < modelIndexListSize; ++iter)
@@ -218,81 +201,43 @@ FragmentOligomerTableView::selectedOligomers(
       else
         processedRowList.append(row);
 
-      // For debugging
-      QModelIndex local_index;
-
-      local_index =
-        oligomerIndex.siblingAtColumn(FRAGMENT_OLIGO_PATTERN_COLUMN);
-      row_text += local_index.data().toString();
-      row_text += " ";
-
-      local_index = oligomerIndex.siblingAtColumn(FRAGMENT_OLIGO_NAME_COLUMN);
-      row_text += local_index.data().toString();
-      row_text += " ";
-
-      local_index = oligomerIndex.siblingAtColumn(FRAGMENT_OLIGO_MONO_COLUMN);
-
-      row_text += local_index.data().toString();
-      row_text += " ";
-
-      local_index = oligomerIndex.siblingAtColumn(FRAGMENT_OLIGO_CHARGE_COLUMN);
-      row_text += local_index.data().toString();
-      row_text += " ";
-
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersRef().at(row);
-
-      libXpertMassCore::OligomerSPtr new_oligomer_sp =
-        std::make_shared<libXpertMassCore::Oligomer>(*oligomer_sp);
-
-      row_text += new_oligomer_sp->getFormulaCstRef().getActionFormula();
-      row_text += "\n";
+      Oligomer *newOligomer = new Oligomer(*mp_oligomerList->at(row));
 
       // Create a NoDeletePointerProp, which might be used later by
       // the user of the list of oligomers to highlight regions in
       // the sequence editor.
 
-      libXpertMassCore::NoDeletePointerProp *prop =
-        new libXpertMassCore::NoDeletePointerProp(
-          "SEQUENCE_EDITOR_WND",
-          static_cast<void *>(mp_parentDlg->editorWnd()));
+      NoDeletePointerProp *prop = new NoDeletePointerProp(
+        "SEQUENCE_EDITOR_WND", static_cast<void *>(mp_parentDlg->editorWnd()));
 
-      new_oligomer_sp->appendProp(prop);
+      newOligomer->appendProp(prop);
 
-      oligomers.getOligomersRef().insert(oligomers.getOligomersRef().begin() +
-                                           oligomers_insertion_index,
-                                         new_oligomer_sp);
+      oligomerList->insert(localIndex, newOligomer);
 
-      ++oligomers_insertion_index;
+      ++localIndex;
       ++count;
     }
 
-  // For debugging.
-  // qDebug().noquote() << row_text;
-  // pappso::Utils::writeToFile(row_text,
-  // QString("/tmp/mass/rows-%1.txt")
-  //.arg(QDateTime::currentDateTime().toString()));
-
   return count;
 }
 
 
 QString *
-FragmentOligomerTableView::describeOligomerAsPlainText(
+FragmentOligomerTableView::selectedOligomersAsPlainText(
   QString delimiter,
   bool withSequence,
   bool forXpertMiner,
-  libXpertMassCore::Enums::MassType massType) const
+  MassType massType) const
 {
   // Let's get all the currently selected oligomers in one list.
-  libXpertMassCore::OligomerCollection oligomers;
+  OligomerList oligomerList;
 
   // Append the selected oligomers to the empty list.
-  std::size_t appended_oligomer_count = selectedOligomers(oligomers, -1);
+  int appendedOligomerCount = selectedOligomers(&oligomerList, -1);
 
   // Sanity check
-  if(appended_oligomer_count != oligomers.size())
-    qFatal() << "Programming error.";
+  if(appendedOligomerCount != oligomerList.size())
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   // If delimiter is empty, then set to "$".
   if(delimiter.isEmpty())
@@ -301,91 +246,69 @@ FragmentOligomerTableView::describeOligomerAsPlainText(
   // Allocate a string in which we describe all the selected items.
 
   // For export to XpertMiner, we only want the masses asked for:
-  // MassType::MONO or MASS_AVG. Also, we want the format to be :
+  // MassType::MASS_MONO or MASS_AVG. Also, we want the format to be :
 
   // mass <delim> charge <delim> name <delim> coords
 
   QString *text = new QString();
 
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_iterator =
-    oligomers.getOligomersRef().begin();
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_end_iterator =
-    oligomers.getOligomersRef().end();
-
-  while(the_iterator != the_end_iterator)
+  while(!oligomerList.isEmpty())
     {
-      if(!forXpertMiner)
-        *text += QString("\n%1%2")
-                   .arg((*the_iterator)->getDescription())
-                   .arg(delimiter);
+      Oligomer *oligomer = oligomerList.takeFirst();
 
-      if(forXpertMiner && massType == libXpertMassCore::Enums::MassType::AVG)
+      if(!forXpertMiner)
+        *text += QString("\n%1%2").arg(oligomer->description()).arg(delimiter);
+
+      if(forXpertMiner && massType == MassType::MASS_AVG)
         {
         }
       else
         {
-          *text +=
-            QString("%1%2")
-              .arg(
-                (*the_iterator)->getMass(libXpertMassCore::Enums::MassType::MONO),
-                0,
-                'f',
-                libXpertMassCore::OLIGOMER_DEC_PLACES)
-              .arg(delimiter);
+          *text += QString("%1%2")
+                     .arg(oligomer->monoString(OLIGOMER_DEC_PLACES))
+                     .arg(delimiter);
         }
 
-      if(forXpertMiner && massType == libXpertMassCore::Enums::MassType::MONO)
+      if(forXpertMiner && massType == MassType::MASS_MONO)
         {
         }
       else
         {
-          *text +=
-            QString("%1%2")
-              .arg((*the_iterator)->getMass(libXpertMassCore::Enums::MassType::AVG),
-                   0,
-                   'f',
-                   libXpertMassCore::OLIGOMER_DEC_PLACES)
-              .arg(delimiter);
+          *text += QString("%1%2")
+                     .arg(oligomer->avgString(OLIGOMER_DEC_PLACES))
+                     .arg(delimiter);
         }
 
-      *text += QString("%1%2")
-                 .arg((*the_iterator)->getIonizerCstRef().charge())
-                 .arg(delimiter);
+      *text += QString("%1%2").arg(oligomer->charge()).arg(delimiter);
 
-      *text += QString("%1%2").arg((*the_iterator)->getName()).arg(delimiter);
+      *text += QString("%1%2").arg(oligomer->name()).arg(delimiter);
 
-      *text += QString("%1%2")
-                 .arg((*the_iterator)
-                        ->getCalcOptionsCstRef()
-                        .getIndexRangeCollectionCstRef()
-                        .positionsAsText())
-                 .arg(delimiter);
+      *text +=
+        QString("%1%2")
+          .arg(static_cast<CoordinateList *>(oligomer)->positionsAsText())
+          .arg(delimiter);
 
       if(!forXpertMiner)
-        *text +=
-          QString("%1%2").arg((*the_iterator)->isModified()).arg(delimiter);
+        *text += QString("%1%2").arg(oligomer->isModified()).arg(delimiter);
 
       // We cannot export the sequence if data are for XpertMiner
       if(!forXpertMiner && withSequence)
         {
-          QString sequence = (*the_iterator)
-                               ->getPolymerCstSPtr()
-                               ->getSequenceCstRef()
-                               .getSequence((*the_iterator)
-                                              ->getCalcOptionsCstRef()
-                                              .getIndexRangeCollectionCstRef());
+          QString *sequence = oligomer->monomerText();
 
-          *text += QString("\n%1").arg(sequence);
+          *text += QString("\n%1").arg(*sequence);
+
+          delete sequence;
         }
 
       // Terminate the stanza
       *text += QString("\n");
 
-      ++the_iterator;
-    }
 
-  // At this point, just clear the oligomers.
-  oligomers.clear();
+      // We can now delete the allocated oligomer, since we do not
+      // need it anymore.
+      delete oligomer;
+    }
 
   // Terminate the string with a new line.
   *text += QString("\n");
@@ -403,7 +326,7 @@ FragmentOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
     }
   else if(mouseEvent->buttons() & Qt::RightButton)
     {
-      contextMenu->popup(mouseEvent->globalPosition().toPoint());
+      contextMenu->popup(mouseEvent->globalPos());
       return;
     }
 
@@ -461,25 +384,18 @@ FragmentOligomerTableView::currentChanged(const QModelIndex &current,
   // tableView (that list actually belongs to the FragmentationDlg
   // instance.
 
-  libXpertMassCore::OligomerSPtr oligomer_sp =
-    mp_oligomers->getOligomersCstRef().at(row);
+  Oligomer *oligomer = mp_oligomerList->at(row);
 
   // If the oligomers obtained with the fragmentation are old and
   // the sequence has been changed since the fragmentation, then the
   // oligomers might point to a sequence element that is no more. We
   // want to avoid such kind of errors.
 
-  if(oligomer_sp->getCalcOptionsCstRef()
-         .getIndexRangeCollectionCstRef()
-         .leftMostIndexRangeStart() >=
-       (qsizetype)oligomer_sp->getPolymerCstSPtr()->size() ||
-     oligomer_sp->getCalcOptionsCstRef()
-         .getIndexRangeCollectionCstRef()
-         .rightMostIndexRangeStop() >=
-       (qsizetype)oligomer_sp->getPolymerCstSPtr()->size())
+  if(oligomer->startIndex() >= oligomer->polymer()->size() ||
+     oligomer->endIndex() >= oligomer->polymer()->size())
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Fragmentation"),
+                           tr("massXpert - Fragmentation"),
                            tr("%1@%2\n"
                               "The monomer indices do not correspond "
                               "to a valid polymer sequence range.\n"
@@ -492,23 +408,24 @@ FragmentOligomerTableView::currentChanged(const QModelIndex &current,
       return;
     }
 
-  QString text =
-    oligomer_sp->getPolymerCstSPtr()->getSequenceCstRef().getSequence(
-      oligomer_sp->getCalcOptionsCstRef().getIndexRangeCollectionCstRef());
+  QString *text = oligomer->polymer()->monomerText(
+    oligomer->startIndex(), oligomer->endIndex(), true);
 
   // We are getting text for an oligomer; it cannot be empty,
   // because that would mean the oligomer has no monomers. In that
   // case it is not conceivable that the oligomer be in the
   // fragmentation product list.
 
-  Q_ASSERT(!text.isEmpty());
+  Q_ASSERT(!text->isEmpty());
 
-  mp_parentDlg->updateOligomerSequence(&text);
+  mp_parentDlg->updateOligomerSequence(text);
+
+  delete text;
 
   // Get the mass calculation engine's options out of the oligomer,
   // so that we can display them correctly.
 
-  libXpertMassCore::CalcOptions calcOptions(oligomer_sp->getCalcOptionsCstRef());
+  CalcOptions calcOptions = oligomer->calcOptions();
 
   mp_parentDlg->updateFragmentationDetails(calcOptions);
 
@@ -533,8 +450,7 @@ FragmentOligomerTableView::itemActivated(const QModelIndex &index)
   // tableView (that list actually belongs to the FragmentationDlg
   // instance.
 
-  libXpertMassCore::OligomerSPtr oligomer_sp =
-    mp_oligomers->getOligomersRef().at(row);
+  Oligomer *oligomer = mp_oligomerList->at(row);
 
   SequenceEditorWnd *editorWnd = mp_parentDlg->editorWnd();
 
@@ -546,17 +462,11 @@ FragmentOligomerTableView::itemActivated(const QModelIndex &index)
   // qDebug() << __FILE__ << __LINE__
   //          << "Elemental composition: " << formula;
 
-  if(oligomer_sp->getCalcOptionsCstRef()
-         .getIndexRangeCollectionCstRef()
-         .leftMostIndexRangeStart() >=
-       (qsizetype)oligomer_sp->getPolymerCstSPtr()->size() ||
-     oligomer_sp->getCalcOptionsCstRef()
-         .getIndexRangeCollectionCstRef()
-         .rightMostIndexRangeStop() >=
-       (qsizetype)oligomer_sp->getPolymerCstSPtr()->size())
+  if(oligomer->startIndex() >= oligomer->polymer()->size() ||
+     oligomer->endIndex() >= oligomer->polymer()->size())
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Fragmentation"),
+                           tr("massXpert - Fragmentation"),
                            tr("%1@%2\n"
                               "The monomer indices do not correspond "
                               "to a valid polymer sequence range.\n"
@@ -570,14 +480,7 @@ FragmentOligomerTableView::itemActivated(const QModelIndex &index)
     }
 
   editorWnd->mpa_editorGraphicsView->setSelection(
-    oligomer_sp->getCalcOptionsCstRef()
-      .getIndexRangeCollectionCstRef()
-      .leftMostIndexRangeStart(),
-    oligomer_sp->getCalcOptionsCstRef()
-      .getIndexRangeCollectionCstRef()
-      .rightMostIndexRangeStop(),
-    false,
-    false);
+    oligomer->startIndex(), oligomer->endIndex(), false, false);
 }
 
 
@@ -586,21 +489,21 @@ FragmentOligomerTableView::itemActivated(const QModelIndex &index)
 void
 FragmentOligomerTableView::copyMono()
 {
-  return copyMassList(libXpertMassCore::Enums::MassType::MONO);
+  return copyMassList(MassType::MASS_MONO);
 }
 
 
 void
 FragmentOligomerTableView::copyAvg()
 {
-  return copyMassList(libXpertMassCore::Enums::MassType::AVG);
+  return copyMassList(MassType::MASS_AVG);
 }
 
 
 void
-FragmentOligomerTableView::copyMassList(libXpertMassCore::Enums::MassType mass_type)
+FragmentOligomerTableView::copyMassList(int monoOrAvg)
 {
-  QString text;
+  QString massList;
 
   // We want to prepare a textual list of masses (either MONO or
   // AVG) of all the oligomers in the tableview, exactly as they are
@@ -624,36 +527,28 @@ FragmentOligomerTableView::copyMassList(libXpertMassCore::Enums::MassType mass_t
 
       // qDebug() << __FILE__ << __LINE__
       //          << "sourceRow:" << sourceRow;
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersRef().at(sourceRow);
 
-      if(mass_type == libXpertMassCore::Enums::MassType::MONO)
-        text += QString("%1").arg(
-          oligomer_sp->getMass(libXpertMassCore::Enums::MassType::MONO),
-          0,
-          'f',
-          libXpertMassCore::OLIGOMER_DEC_PLACES);
-      else if(mass_type == libXpertMassCore::Enums::MassType::AVG)
-        text += QString("%1").arg(
-          oligomer_sp->getMass(libXpertMassCore::Enums::MassType::AVG),
-          0,
-          'f',
-          libXpertMassCore::OLIGOMER_DEC_PLACES);
+      Oligomer *oligomer = mp_oligomerList->at(sourceRow);
+
+      if(monoOrAvg == MassType::MASS_MONO)
+        massList += oligomer->monoString(OLIGOMER_DEC_PLACES);
+      else if(monoOrAvg == MassType::MASS_AVG)
+        massList += oligomer->avgString(OLIGOMER_DEC_PLACES);
       else
-        qFatal() << "Programming error.";
+        qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
       // End the mass item with a new line.
-      text += "\n";
+      massList += "\n";
     }
 
-  if(text.isEmpty())
+  if(massList.isEmpty())
     return;
 
   QClipboard *clipboard = QApplication::clipboard();
 
-  clipboard->setText(text, QClipboard::Clipboard);
+  clipboard->setText(massList, QClipboard::Clipboard);
 }
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
