@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,35 +30,28 @@
  * END software license
  */
 
-#pragma once
 
-/////////////////////// stdlib includes
+#ifndef FRAGMENT_OLIGOMER_TABLE_VIEW_MIME_DATA_HPP
+#define FRAGMENT_OLIGOMER_TABLE_VIEW_MIME_DATA_HPP
 
 
 /////////////////////// Qt includes
 #include <QMimeData>
 
 
-/////////////////////// pappsomspp includes
-
-
-/////////////////////// libXpertMass includes
-
-
-/////////////////////// libXpertMassGui includes
-
-
 /////////////////////// Local includes
 #include "FragmentOligomerTableView.hpp"
 #include "SequenceEditorWnd.hpp"
 #include "FragmentationDlg.hpp"
 
 
-namespace MsXpS
-{
-namespace MassXpert
+namespace msxps
 {
 
+	namespace massxpert
+	{
+
+
 
 class FragmentOligomerTableViewMimeData : public QMimeData
 {
@@ -75,7 +68,7 @@ class FragmentOligomerTableViewMimeData : public QMimeData
   QString selectionAsPlainText() const;
 
   protected:
-  QVariant retrieveData(const QString &, QMetaType) const;
+  QVariant retrieveData(const QString &, QVariant::Type) const;
 
   public:
   FragmentOligomerTableViewMimeData(const FragmentOligomerTableView *,
@@ -87,6 +80,9 @@ class FragmentOligomerTableViewMimeData : public QMimeData
   QStringList formats() const;
 };
 
+} // namespace massxpert
 
-} // namespace MassXpert
-} // namespace MsXpS
+} // namespace msxps
+
+
+#endif // FRAGMENT_OLIGOMER_TABLE_VIEW_MIME_DATA_HPP
