@@ -36,13 +36,12 @@
 #include <QMouseEvent>
 #include <QHeaderView>
 #include <QMessageBox>
-#include <libXpertMass/PolChemDefEntity.hpp>
 
 /////////////////////// Local includes
 #include "MzLabInputOligomerTableView.hpp"
 #include "MzLabInputOligomerTableViewModel.hpp"
 
-#include <libXpertMass/Oligomer.hpp>
+#include "../nongui/Oligomer.hpp"
 
 #include "MzLabInputOligomerTableViewDlg.hpp"
 
@@ -50,14 +49,14 @@
 #include "FragmentOligomerTableViewMimeData.hpp"
 #include "MassSearchOligomerTableViewMimeData.hpp"
 
-#include <libXpertMass/Coordinates.hpp>
+#include "../nongui/Coordinates.hpp"
 
-
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
+
 
 
 MzLabInputOligomerTableView::MzLabInputOligomerTableView(QWidget *parent)
@@ -159,7 +158,7 @@ MzLabInputOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
 }
 
 
-libXpertMass::MassType
+MassType
 MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
 {
   // Each time a new drop/paste happens, we have to perform some
@@ -169,10 +168,10 @@ MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
   // as the mass type for the parent dialog window. Ask what's being
   // currently checked (mono and avg are two checkboxes).
 
-  libXpertMass::MassType previousMassType = mp_parentDlg->previousMassType();
-  libXpertMass::MassType massType         = mp_parentDlg->massType();
+  MassType previousMassType = mp_parentDlg->previousMassType();
+  MassType massType         = mp_parentDlg->massType();
 
-  if(massType == libXpertMass::MassType::MASS_NONE)
+  if(massType == MassType::MASS_NONE)
     {
       // Ask the user to clearly indicate what is the mass type
       // required).
@@ -185,7 +184,7 @@ MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
   // Check if one drop already occurred in the past and if it was
   // with the same mass type as now. Otherwise alert the user.
 
-  if(previousMassType != libXpertMass::MassType::MASS_NONE &&
+  if(previousMassType != MassType::MASS_NONE &&
      previousMassType != massType)
     {
       int ret = QMessageBox::question(this,
@@ -197,7 +196,7 @@ MzLabInputOligomerTableView::pasteOrDropMassTypeCheck()
 
       if(ret == QMessageBox::No)
         {
-          return libXpertMass::MassType::MASS_NONE;
+          return MassType::MASS_NONE;
         }
     }
 
@@ -241,9 +240,9 @@ MzLabInputOligomerTableView::dragMoveEvent(QDragMoveEvent *event)
 void
 MzLabInputOligomerTableView::pasteEvent()
 {
-  libXpertMass::MassType massType = pasteOrDropMassTypeCheck();
+  MassType massType = pasteOrDropMassTypeCheck();
 
-  if(massType == libXpertMass::MassType::MASS_NONE)
+  if(massType == MassType::MASS_NONE)
     {
       // The user did not want to answer positively to our
       // question. Conservatory behaviour.
@@ -307,9 +306,9 @@ MzLabInputOligomerTableView::pasteEvent()
 void
 MzLabInputOligomerTableView::dropEvent(QDropEvent *event)
 {
-  libXpertMass::MassType massType = pasteOrDropMassTypeCheck();
+  MassType massType = pasteOrDropMassTypeCheck();
 
-  if(massType == libXpertMass::MassType::MASS_NONE)
+  if(massType == MassType::MASS_NONE)
     {
       // The user did not want to answer positively to our
       // question. Conservatory behaviour.
@@ -384,8 +383,7 @@ int
 MzLabInputOligomerTableView::testCleaveOligomerDataDropped(
   QDropEvent *event, OligomerList *oligomerList)
 {
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
   const CleaveOligomerTableViewMimeData *tableViewMimeData =
     qobject_cast<const CleaveOligomerTableViewMimeData *>(event->mimeData());
@@ -413,9 +411,9 @@ MzLabInputOligomerTableView::testCleaveOligomerDataDropped(
 
   for(int iter = 0; iter < oligomerList->size(); ++iter)
     {
-      libXpertMass::OligomerSPtr oligomer_sp = oligomerList->at(iter);
+      Oligomer *oligomer = oligomerList->at(iter);
 
-      oligomer_sp->setPolChemDefCstSPtr(polChemDefCstSPtr);
+      oligomer->setPolChemDef(polChemDef);
     }
 
   return count;
@@ -426,8 +424,7 @@ int
 MzLabInputOligomerTableView::testMassSearchOligomerDataDropped(
   QDropEvent *event, OligomerList *oligomerList)
 {
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
   const MassSearchOligomerTableViewMimeData *tableViewMimeData =
     qobject_cast<const MassSearchOligomerTableViewMimeData *>(
@@ -456,9 +453,9 @@ MzLabInputOligomerTableView::testMassSearchOligomerDataDropped(
 
   for(int iter = 0; iter < oligomerList->size(); ++iter)
     {
-      libXpertMass::OligomerSPtr oligomer_sp = oligomerList->at(iter);
+      Oligomer *oligomer = oligomerList->at(iter);
 
-      oligomer_sp->setPolChemDefCstSPtr(polChemDefCstSPtr);
+      oligomer->setPolChemDef(polChemDef);
     }
 
   return count;
@@ -480,7 +477,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
 
   // First, split the text file into lines.
   QStringList stringList =
-    text.split("\n", Qt::SkipEmptyParts, Qt::CaseSensitive);
+    text.split("\n", QString::SkipEmptyParts, Qt::CaseSensitive);
   // qDebug() << __FILE__ << __LINE__
   //          << "stringList:" << stringList;
 
@@ -501,7 +498,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
       // qDebug() << __FILE__ << __LINE__
       //          << "text:" << text;
 
-      QStringList stringList = text.split(delimiter, Qt::SkipEmptyParts);
+      QStringList stringList = text.split(delimiter, QString::SkipEmptyParts);
 
       // qDebug() << __FILE__ << __LINE__
       //          << "stringList:" << stringList;
@@ -509,7 +506,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
 
       int stringListSize = stringList.size();
 
-      libXpertMass::OligomerSPtr oligomer_sp = nullptr;
+      Oligomer *oligomer = 0;
 
       if(stringListSize == 0)
         {
@@ -524,20 +521,20 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
         }
       else if(stringListSize == 1)
         {
-          oligomer_sp = parseOnlyMassLine(stringList);
+          oligomer = parseOnlyMassLine(stringList);
         }
       else if(stringListSize == 2)
         {
-          oligomer_sp = parseMassAndChargeLine(stringList);
+          oligomer = parseMassAndChargeLine(stringList);
         }
       else // (stringListSize > 2)
         {
-          oligomer_sp = parseFullLine(stringList);
+          oligomer = parseFullLine(stringList);
         }
 
       // At this point we should have one oligomer back from the
       // called function.
-      if(oligomer_sp == nullptr)
+      if(!oligomer)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Drag and drop"),
@@ -551,7 +548,7 @@ MzLabInputOligomerTableView::testSimpleTextDataDroppedOrPasted(
         }
       else
         {
-          oligomerList->append(oligomer_sp);
+          oligomerList->append(oligomer);
           count++;
         }
     }
@@ -584,16 +581,15 @@ MzLabInputOligomerTableView::testSimpleTextDataDropped(
 }
 
 
-libXpertMass::OligomerSPtr
+Oligomer *
 MzLabInputOligomerTableView::parseOnlyMassLine(QStringList &stringList)
 {
   // There is only the mass in the line.
 
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
-  libXpertMass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
-  int totalCharge                = ionizeRule.charge() * ionizeRule.level();
+  IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
+  int totalCharge = ionizeRule.charge() * ionizeRule.level();
 
   bool ok     = false;
   double mass = stringList.first().toDouble(&ok);
@@ -611,20 +607,21 @@ MzLabInputOligomerTableView::parseOnlyMassLine(QStringList &stringList)
       return 0;
     }
 
+  Oligomer *oligomer = 0;
+
   // Note that if the ionizeRule has a total charge
   //(charge() * level()), then we have to set this
   // oligomer to charged state(totalCharge ? true : false).
-  libXpertMass::OligomerSPtr oligomer_sp =
-    std::make_shared<libXpertMass::Oligomer>(polChemDefCstSPtr,
-                                        "NOT_SET" /*name*/,
-                                        QString("") /*description*/,
-                                        false /*modified*/,
-                                        libXpertMass::Ponderable(mass, mass),
-                                        ionizeRule,
-                                        libXpertMass::CalcOptions(),
-                                        (totalCharge ? true : false),
-                                        -1,
-                                        -1);
+  oligomer = new Oligomer(polChemDef,
+                          "NOT_SET" /*name*/,
+                          QString("") /*description*/,
+                          false /*modified*/,
+                          Ponderable(mass, mass),
+                          ionizeRule,
+                          CalcOptions(),
+                          (totalCharge ? true : false),
+                          -1,
+                          -1);
 
   // qDebug() << __FILE__ << __LINE__
   //          << "ionizerule:" << ionizeRule.charge()
@@ -634,20 +631,19 @@ MzLabInputOligomerTableView::parseOnlyMassLine(QStringList &stringList)
   //          << "charge:" << oligomer->charge();
   // oligomer->ionizeRule().debugPutStdErr();
 
-  return oligomer_sp;
+  return oligomer;
 }
 
 
-libXpertMass::OligomerSPtr
+Oligomer *
 MzLabInputOligomerTableView::parseMassAndChargeLine(QStringList &stringList)
 {
   // One mass, one charge.
 
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
-  libXpertMass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
-  int totalCharge                = ionizeRule.charge() * ionizeRule.level();
+  IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
+  int totalCharge = ionizeRule.charge() * ionizeRule.level();
 
   bool ok     = false;
   double mass = stringList.first().toDouble(&ok);
@@ -684,37 +680,35 @@ MzLabInputOligomerTableView::parseMassAndChargeLine(QStringList &stringList)
   // Note that if the ionizeRule has a total charge
   //(charge() * level()), then we have to set this
   // oligomer to charged state(totalCharge ? true : false).
-  libXpertMass::OligomerSPtr oligomer_sp =
-    std::make_shared<libXpertMass::Oligomer>(polChemDefCstSPtr,
-                                        "NOT_SET" /*name*/,
-                                        QString("") /*description*/,
-                                        false /*modified*/,
-                                        libXpertMass::Ponderable(mass, mass),
-                                        ionizeRule,
-                                        libXpertMass::CalcOptions(),
-                                        (totalCharge ? true : false),
-                                        -1,
-                                        -1);
+  Oligomer *oligomer = new Oligomer(polChemDef,
+                                    "NOT_SET" /*name*/,
+                                    QString("") /*description*/,
+                                    false /*modified*/,
+                                    Ponderable(mass, mass),
+                                    ionizeRule,
+                                    CalcOptions(),
+                                    (totalCharge ? true : false),
+                                    -1,
+                                    -1);
 
   // qDebug() << __FILE__ << __LINE__
   //          << "charge:" << oligomer->charge();
   // oligomer->ionizeRule().debugPutStdErr();
 
-  return oligomer_sp;
+  return oligomer;
 }
 
 
-libXpertMass::OligomerSPtr
+Oligomer *
 MzLabInputOligomerTableView::parseFullLine(QStringList &stringList)
 {
   // One mass, one charge and even the name of the oligomer and of the
   // coordinates of that oligomer.
 
-  libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr =
-    mp_mzLabWnd->polChemDefCstSPtr();
+  PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
 
-  libXpertMass::IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
-  int totalCharge                = ionizeRule.charge() * ionizeRule.level();
+  IonizeRule ionizeRule = mp_mzLabWnd->ionizeRule();
+  int totalCharge = ionizeRule.charge() * ionizeRule.level();
 
   bool ok     = false;
   double mass = stringList.first().toDouble(&ok);
@@ -785,22 +779,21 @@ MzLabInputOligomerTableView::parseFullLine(QStringList &stringList)
   // Note that if the ionizeRule has a total charge
   //(charge() * level()), then we have to set this
   // oligomer to charged state(totalCharge ? true : false).
-  libXpertMass::OligomerSPtr oligomer_sp =
-    std::make_shared<libXpertMass::Oligomer>(polChemDefCstSPtr,
-                                        oligoName,
-                                        QString("") /*description*/,
-                                        false /*modified*/,
-                                        libXpertMass::Ponderable(mass, mass),
-                                        ionizeRule,
-                                        libXpertMass::CalcOptions(),
-                                        (totalCharge ? true : false),
-                                        -1,
-                                        -1);
+  Oligomer *oligomer = new Oligomer(polChemDef,
+                                    oligoName,
+                                    QString("") /*description*/,
+                                    false /*modified*/,
+                                    Ponderable(mass, mass),
+                                    ionizeRule,
+                                    CalcOptions(),
+                                    (totalCharge ? true : false),
+                                    -1,
+                                    -1);
 
   // Set coordinates as previously characterized.
-  oligomer_sp->setCoordinates(coordinates);
+  oligomer->setCoordinates(coordinates);
 
-  return oligomer_sp;
+  return oligomer;
 }
 
 
@@ -961,7 +954,7 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
 
   int row = sourceIndex.row();
 
-  libXpertMass::OligomerSPtr oligomer_sp = mp_oligomerList->at(row);
+  Oligomer *oligomer = mp_oligomerList->at(row);
 
   // We may have two situations here with the data in the table view
   //  coming
@@ -978,14 +971,14 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
 
   SequenceEditorWnd *editorWnd = 0;
 
-  const libXpertMass::Polymer *polymer = oligomer_sp->polymer();
+  const Polymer *polymer = oligomer->polymer();
 
   if(polymer)
     {
       // There must be a pointer to the sequence editor window.
 
-      libXpertMass::Prop *prop = const_cast<libXpertMass::Oligomer *>(oligomer_sp.get())
-                              ->prop("SEQUENCE_EDITOR_WND");
+      Prop *prop =
+        const_cast<Oligomer *>(oligomer)->prop("SEQUENCE_EDITOR_WND");
 
       if(prop)
         {
@@ -1013,16 +1006,15 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
       return;
     }
 
-  libXpertMass::CoordinateList *coordinateList =
-    static_cast<libXpertMass::CoordinateList *>(
-      const_cast<libXpertMass::Oligomer *>(oligomer_sp.get()));
+  CoordinateList *coordinateList =
+    static_cast<CoordinateList *>(const_cast<Oligomer *>(oligomer));
 
   // Remove the previous selection, so that we can start fresh.
   editorWnd->mpa_editorGraphicsView->resetSelection();
 
   for(int iter = 0; iter < coordinateList->size(); ++iter)
     {
-      libXpertMass::Coordinates *coordinates = coordinateList->at(iter);
+      Coordinates *coordinates = coordinateList->at(iter);
 
       int start = coordinates->start();
       int end   = coordinates->end();
@@ -1057,4 +1049,4 @@ MzLabInputOligomerTableView::itemActivated(const QModelIndex &index)
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
