@@ -40,12 +40,12 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/globals.hpp>
+#include "../nongui/globals.hpp"
 #include "ui_MzLabInputOligomerTableViewDlg.h"
 #include "MzLabInputOligomerTableViewSortProxyModel.hpp"
 #include "SequenceEditorWnd.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -79,13 +79,13 @@ class MzLabInputOligomerTableViewDlg : public QDialog
   // a total rewrite of the way fragmentation-generated oligomers
   // ionize. So there is no more the m_isFragment member datum.
 
-  libXpertMass::MassType m_massType;
+  MassType m_massType;
   // Indicates if data were already imported with a mass type, so
   // that if another import is done with another mass type, then the
   // user is alerted that he is mixing masses of different mass
   // types. When the dialog is constructed the value is "NONE" since
   // we do not know what kind of masses the user will import.
-  libXpertMass::MassType m_previousMassType;
+  MassType m_previousMassType;
 
   MzLabInputOligomerTableViewModel *mpa_oligomerTableViewModel;
   MzLabInputOligomerTableViewSortProxyModel *mpa_proxyModel;
@@ -95,7 +95,7 @@ class MzLabInputOligomerTableViewDlg : public QDialog
   void closeEvent(QCloseEvent *event);
 
   public:
-  MzLabInputOligomerTableViewDlg(QWidget *, QString, libXpertMass::MassType);
+  MzLabInputOligomerTableViewDlg(QWidget *, QString, MassType);
 
   ~MzLabInputOligomerTableViewDlg();
 
@@ -110,17 +110,17 @@ class MzLabInputOligomerTableViewDlg : public QDialog
 
   int duplicateOligomerData(const OligomerList &);
 
-  libXpertMass::MassType massType();
-  libXpertMass::MassType previousMassType();
-  void setPreviousMassType(libXpertMass::MassType);
+  MassType massType();
+  MassType previousMassType();
+  void setPreviousMassType(MassType);
 
-  libXpertMass::MassType massTypeQuery();
+  MassType massTypeQuery();
 
-  void applyFormula(const libXpertMass::Formula &, bool);
+  void applyFormula(const Formula &, bool);
   void applyMass(double, bool);
   void applyThreshold(double, bool, bool);
   void applyChargeIncrement(int, bool);
-  void applyIonizeRule(const libXpertMass::IonizeRule &, bool);
+  void applyIonizeRule(const IonizeRule &, bool);
 
   public slots:
   void monoMassCheckBoxStateChanged(int);
@@ -132,7 +132,7 @@ class MzLabInputOligomerTableViewDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_DLG_HPP
