@@ -43,7 +43,7 @@
 #include "../nongui/OligomerPair.hpp"
 #include "../nongui/OligomerList.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -67,7 +67,7 @@ class MzLabOutputOligomerTableView : public QTableView
   MzLabOutputOligomerTableViewModel *mp_sourceModel;
 
   // We do not own that oligomerPair list.
-  QList<OligomerPairSPtr> *mp_oligomerPairList;
+  QList<OligomerPair *> *mp_oligomerPairList;
 
 
   protected:
@@ -78,8 +78,8 @@ class MzLabOutputOligomerTableView : public QTableView
   void setSourceModel(MzLabOutputOligomerTableViewModel *);
   MzLabOutputOligomerTableViewModel *sourceModel();
 
-  void setOligomerPairList(QList<OligomerPairSPtr> *);
-  const QList<OligomerPairSPtr> *oligomerPairList();
+  void setOligomerPairList(QList<OligomerPair *> *);
+  const QList<OligomerPair *> *oligomerPairList();
 
   void setParentDlg(MzLabOutputOligomerTableViewDlg *);
   MzLabOutputOligomerTableViewDlg *parentDlg();
@@ -87,7 +87,7 @@ class MzLabOutputOligomerTableView : public QTableView
   void setMzLabWnd(MzLabWnd *);
   MzLabWnd *mzLabWnd();
 
-  void provideEditorWindowFeedback(const libXpertMass::OligomerSPtr);
+  void provideEditorWindowFeedback(const Oligomer *);
 
   QString *selectedDataAsPlainText();
 
@@ -99,7 +99,7 @@ class MzLabOutputOligomerTableView : public QTableView
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_OUTPUT_OLIGOMER_TABLE_VIEW_HPP
