@@ -42,17 +42,18 @@
 #include "MzLabWnd.hpp"
 #include "MzLabOutputOligomerTableViewModel.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
+
 
 
 MzLabOutputOligomerTableViewDlg::MzLabOutputOligomerTableViewDlg(
   QWidget *parent,
-  QList<OligomerPairSPtr> *oligomerPairList,
-  libXpertMass::MassType massType,
+  QList<OligomerPair *> *oligomerPairList,
+  MassType massType,
   MzLabInputOligomerTableViewDlg *dlg1,
   MzLabInputOligomerTableViewDlg *dlg2,
   const QString &dlg1Name,
@@ -101,7 +102,14 @@ MzLabOutputOligomerTableViewDlg::~MzLabOutputOligomerTableViewDlg()
 {
   delete mpa_oligomerTableViewModel;
 
-  mpa_oligomerPairList->clear();
+  while(mpa_oligomerPairList->size())
+    {
+      delete mpa_oligomerPairList->takeFirst();
+      //	qDebug() << __FILE__ << __LINE__
+      //		 << "Deleting one oligomer";
+    }
+
+  mpa_oligomerPairList = 0;
 }
 
 
@@ -173,7 +181,6 @@ MzLabOutputOligomerTableViewDlg::exportToClipboard()
   clipboard->setText(text, QClipboard::Clipboard);
 }
 
-
 void
 MzLabOutputOligomerTableViewDlg::exportSelectedAsNewList()
 {
@@ -202,10 +209,13 @@ MzLabOutputOligomerTableViewDlg::exportSelectedAsNewList()
     qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
   // At this point, free the oligomers in the tempOligomerList.
+  while(tempOligomerList.size())
+    delete tempOligomerList.takeFirst();
+
   tempOligomerList.clear();
 }
 
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
