@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,23 +39,19 @@
 #include <QDebug>
 
 #include "SeqToolsDlg.hpp"
-#include "Application.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
+	namespace massxpert
+	{
+
+
+
+
+SeqToolsDlg::SeqToolsDlg(QWidget *parent) : QDialog(parent, Qt::Dialog)
 {
-
-
-SeqToolsDlg::SeqToolsDlg(QWidget *parent,
-                         const QString &application_name,
-                         const QString &description)
-  : QDialog(parent, Qt::Dialog)
-  {
-    setWindowIcon(qApp->windowIcon());
-
   mp_parent = static_cast<QMainWindow *>(parent);
 
   m_strictCodeLength = false;
@@ -63,7 +59,7 @@ SeqToolsDlg::SeqToolsDlg(QWidget *parent,
 
   QVBoxLayout *mainLayout = new QVBoxLayout;
 
-  QLabel *label = new QLabel(tr("Sequence Manipulations"));
+  QLabel *label = new QLabel(tr("Sequence Manipulation Tools Plugin"));
 
   mainLayout->addWidget(label, 0, Qt::AlignHCenter);
 
@@ -84,9 +80,7 @@ SeqToolsDlg::SeqToolsDlg(QWidget *parent,
 
   setAttribute(Qt::WA_DeleteOnClose);
 
-  // Update the window title because the window title element in m_ui might be
-  // either erroneous or empty.
-  setWindowTitle(QString("%1 - %2").arg(application_name).arg(description));
+  setWindowTitle(tr("Sequence Manipulation Tools Plugin"));
 
   connect(mp_parent, SIGNAL(aboutToClose()), this, SLOT(parentClosing()));
 }
@@ -152,6 +146,7 @@ SeqToolsDlg::createActionGroupBox()
 void
 SeqToolsDlg::loadDictionary()
 {
+
   // Reinitialize the two critical variables
   m_strictCodeLength = false;
   m_strictCodeCase   = false;
@@ -173,15 +168,13 @@ SeqToolsDlg::loadDictionary()
                                  tr("Dictionary files(*.dic)"));
 
   if(!QFile::exists(filePath))
-    {
-      qDebug() << "Could not find the file: " << filePath;
-      return;
-    }
+    return;
 
   // Load the file and for each line deconstruct the item into two
   // QString objects that are used to make a QHash entry in
   // QHash<QString, QString> m_dictionaryHash.
 
+  qint64 lineLength;
   QString line;
   char buffer[1024];
 
@@ -189,55 +182,47 @@ SeqToolsDlg::loadDictionary()
 
   if(!file.open(QFile::ReadOnly))
     {
-      qDebug() << "Failed to open the file for read:" << filePath;
       m_dictionaryLoaded = false;
       return;
     }
 
-  while(file.readLine(buffer, sizeof(buffer)) != -1)
-    {
-      // qDebug() << "Current line:" << buffer;
+  lineLength = file.readLine(buffer, sizeof(buffer));
 
+  while(lineLength != -1)
+    {
       // The line is now in buffer, and we want to convert
       // it to Unicode by setting it in a QString.
       line = buffer;
 
-      line = line.simplified();
-
-      // If there were only space characters (tab, newline, space)
-      // then the line is now empty, just go the next one.
-      if(!line.size())
-        continue;
-
       if(line.startsWith('#'))
         {
-          file.readLine(buffer, sizeof(buffer));
+          lineLength = file.readLine(buffer, sizeof(buffer));
           continue;
         }
 
-      if(line == "strictCodeLength")
+      if(line.simplified() == "strictCodeLength")
         {
           m_strictCodeLength = true;
 
-          file.readLine(buffer, sizeof(buffer));
+          lineLength = file.readLine(buffer, sizeof(buffer));
           continue;
         }
 
-      if(line == "strictCodeCase")
+      if(line.simplified() == "strictCodeCase")
         {
           m_strictCodeCase = true;
 
-          file.readLine(buffer, sizeof(buffer));
+          lineLength = file.readLine(buffer, sizeof(buffer));
           continue;
         }
 
-      QStringList stringList = line.split(">", Qt::SkipEmptyParts);
+      QStringList stringList = line.split(">", QString::SkipEmptyParts);
 
       if(stringList.size() != 2)
         {
           QMessageBox::warning(this,
                                tr("Sequence Manipulation Tools Plugin"),
-                               tr("The parsed line has not the right format."),
+                               tr("Failed to load dictionary."),
                                QMessageBox::Ok);
 
           m_dictionaryLoaded = false;
@@ -250,18 +235,16 @@ SeqToolsDlg::loadDictionary()
       else if(stringList.last().endsWith('\n'))
         stringList.last().chop(1);
 
-      if(stringList.first().contains(QRegularExpression("[0-9]")))
+      if(stringList.first().contains(QRegExp("[0-9]")))
         {
           bool ok           = false;
           m_inputCodeLength = stringList.first().toInt(&ok, 10);
 
-          // qDebug() << "The input code length:" << m_inputCodeLength;
-
           if(!m_inputCodeLength && !ok)
             {
               QMessageBox::warning(this,
                                    tr("Sequence Manipulation Tools Plugin"),
-                                   tr("Failed to parse the input code length."),
+                                   tr("Failed to load dictionary."),
                                    QMessageBox::Ok);
 
               m_dictionaryLoaded = false;
@@ -273,21 +256,20 @@ SeqToolsDlg::loadDictionary()
 
           m_outputCodeLength = stringList.last().toInt(&ok, 10);
 
-          // qDebug() << "The output code length:" << m_outputCodeLength;
-
           if(!m_outputCodeLength && !ok)
             {
-              QMessageBox::warning(
-                this,
-                tr("Sequence Manipulation Tools Plugin"),
-                tr("Failed to parse the output code length."),
-                QMessageBox::Ok);
+              QMessageBox::warning(this,
+                                   tr("Sequence Manipulation Tools Plugin"),
+                                   tr("Failed to load dictionary."),
+                                   QMessageBox::Ok);
 
               m_dictionaryLoaded = false;
               file.close();
               return;
             }
 
+          lineLength = file.readLine(buffer, sizeof(buffer));
+
           continue;
         }
 
@@ -299,25 +281,22 @@ SeqToolsDlg::loadDictionary()
 
       if(!m_strictCodeCase)
         {
-          // qDebug() << "Inserting" << stringList.first().toUpper() << ":" <<
-          // stringList.last();
-
           m_dictionaryHash.insert(stringList.first().toUpper(),
                                   stringList.last());
         }
       else
         {
-          // qDebug() << "Inserting" << stringList.first() << ":" <<
-          // stringList.last();
-
           m_dictionaryHash.insert(stringList.first(), stringList.last());
         }
+
+      lineLength = file.readLine(buffer, sizeof(buffer));
     }
 
   file.close();
 
-  // qDebug() << "input/output code lengths" << m_inputCodeLength << "/"
-  //          << m_outputCodeLength;
+  //   qDebug() << __FILE__ << __LINE__
+  // 	    << "input/output code lengths"
+  // 	    << m_inputCodeLength << "/" << m_outputCodeLength;
 
   if(m_dictionaryHash.size())
     m_dictionaryLoaded = true;
@@ -376,16 +355,6 @@ SeqToolsDlg::execute()
 
       QString docText = mp_inputEditor->toPlainText();
 
-      // We can purify the text by eliminating classical characters that
-      // do not ship any sequence information: spaces, \' or \", \., \d,
-      // for example.
-
-      // qDebug() << "Before spurious chars removal:" << docText;
-
-      docText.remove(QRegularExpression("[\\s\\d\"\'\\.]*"));
-
-      // qDebug() << "After spurious chars removal:" << docText;
-
       QStringList codeList;
 
       if(!makeCodeList(docText, codeList))
@@ -506,9 +475,9 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
   //   qDebug()  << __FILE__ << __LINE__
   // 	    << "index:" << *index;
 
-  // At this point there are different situations :
+  // At this point there are differnt situations :
 
-  // 1. The input code length is strict, that is, the rule is the
+  // 1. The input code length is strict, that is the rule is the
   // number of characters in the input code has to be equal to what
   // specified in the file.
 
@@ -527,7 +496,7 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
 
           int residualCharacters = textLength - *index;
 
-          // Get those residual characters.
+          // Get those two residual characters.
 
           newCode = text.mid(*index, residualCharacters);
 
@@ -597,8 +566,8 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
                 }
             }
 
-          // At this point we know that the characters are correct in number
-          // and in case.
+          // At this point we know that the characters are correct in number and
+          // in case.
         }
       // End of
       // if(m_strictCodeCase)
@@ -709,6 +678,6 @@ SeqToolsDlg::nextCode(QString &text, QString *code, int *index)
 }
 
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
