@@ -1,18 +1,18 @@
 /*  BEGIN software license
  *
- *  MsXpertSuite - mass spectrometry software suite
+ *  msXpertSuite - mass spectrometry software suite
  *  -----------------------------------------------
- *  Copyright(C) 2009, 2026 Filippo Rusconi
+ *  Copyright(C) 2009, 2017 Filippo Rusconi
  *
  *  http://www.msxpertsuite.org
  *
- *  This file is part of the MsXpertSuite project.
+ *  This file is part of the msXpertSuite project.
  *
- *  The MsXpertSuite project is the successor of the massXpert project. This
+ *  The msXpertSuite project is the successor of the massXpert project. This
  *  project now includes various independent modules:
  *
- *  - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,11 +31,11 @@
  */
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
 
 
 QString gpl(
@@ -136,8 +136,7 @@ QString gpl(
   "  To \"propagate\" a work means to do anything with it that, without\n"
   "permission, would make you directly or secondarily liable for\n"
   "infringement under applicable copyright law, except executing it on a\n"
-  "computer or modifying a private copy.  libXpertMassCore::Propagation includes "
-  "copying,\n"
+  "computer or modifying a private copy.  Propagation includes copying,\n"
   "distribution (with or without modification), making available to the\n"
   "public, and in some countries other activities as well.\n"
   "\n"
@@ -250,7 +249,7 @@ QString gpl(
   "  You may charge any price or no price for each copy that you convey,\n"
   "and you may offer support or warranty protection for a fee.\n"
   "\n"
-  "  5. Conveying libXpertMassCore::Modified Source Versions.\n"
+  "  5. Conveying Modified Source Versions.\n"
   "\n"
   "  You may convey a work based on the Program, or the modifications to\n"
   "produce it from the Program, in the form of source code under the\n"
@@ -778,6 +777,6 @@ QString gplLegalDisclaimerLiabilitySections(
   "SUCH DAMAGES.\n"
   "\n");
 
-} // namespace MassXpert
+	} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
