@@ -36,32 +36,44 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/FragSpec.hpp>
+#include "FragSpec.hpp"
 #include "FragOptions.hpp"
-#include <libXpertMass/CalcOptions.hpp>
-#include <libXpertMass/Polymer.hpp>
-#include <libXpertMass/IonizeRule.hpp>
+#include "CalcOptions.hpp"
+#include "Polymer.hpp"
+#include "IonizeRule.hpp"
 #include "OligomerList.hpp"
 #include "CrossLinkedRegion.hpp"
-#include <libXpertMass/PolChemDefEntity.hpp>
 
-namespace MsXpS
-{
+namespace msxps {
 
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
 class Fragmenter
 {
+  private:
+  const QPointer<Polymer> mp_polymer;
+  const PolChemDef *mp_polChemDef;
+  QList<FragOptions *> m_fragOptionList;
+  CalcOptions m_calcOptions;
+  IonizeRule m_ionizeRule;
+
+  // Pointer to an oligomer list which WE DO NOT OWN.
+  OligomerList *mp_oligomerList;
+
+  // A list of CrossLinkedRegion instances that we compute in case
+  // there are cross-links in the fragmented sequence.
+  QList<CrossLinkedRegion *> m_crossLinkedRegionList;
+
 
   public:
-  Fragmenter(libXpertMass::Polymer *,
-             libXpertMass::PolChemDefCstSPtr,
+  Fragmenter(Polymer *,
+             const PolChemDef *,
              const QList<FragOptions *> &fragOptionList,
-             const libXpertMass::CalcOptions &,
-             const libXpertMass::IonizeRule &);
+             const CalcOptions &,
+             const IonizeRule &);
 
   Fragmenter(const Fragmenter &);
   ~Fragmenter();
@@ -76,31 +88,16 @@ class Fragmenter
   int fragmentEndLeft(FragOptions &);
   int fragmentEndRight(FragOptions &);
 
-  bool
-  accountFragRule(libXpertMass::FragRule *, bool, int, int, libXpertMass::Ponderable *);
+  bool accountFragRule(FragRule *, bool, int, int, Ponderable *);
   int accountFormulas(OligomerList *, FragOptions &, QString, int);
   OligomerList *accountIonizationLevels(OligomerList *, FragOptions &);
 
   void emptyOligomerList();
-
-  private:
-  libXpertMass::Polymer *mp_polymer;
-  libXpertMass::PolChemDefCstSPtr mcsp_polChemDef;
-  QList<FragOptions *> m_fragOptionList;
-  libXpertMass::CalcOptions m_calcOptions;
-  libXpertMass::IonizeRule m_ionizeRule;
-
-  // Pointer to an oligomer list which WE DO NOT OWN.
-  OligomerList *mp_oligomerList;
-
-  // A list of CrossLinkedRegion instances that we compute in case
-  // there are cross-links in the fragmented sequence.
-  QList<CrossLinkedRegion *> m_crossLinkedRegionList;
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // FRAGMENTER_HPP
