@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,11 +40,12 @@
 /////////////////////// Local includes
 #include "MassSpectrum.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
 
 
 //! The MsMultiHash class provides a multi-hash relating double values with
@@ -74,6 +75,6 @@ class MsMultiHash : public QMultiHash<double, MassSpectrum *>
 };
 
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
